<?php
/**
 * @package     Uso da biblioteca de sessao do Framework Joomla
 * @subpackage  Criar uma sessão com banco de dados
 * @author		Johnny Salazar Reidel
 * @email		johnny@noboss.com.br
 * @copyright   No Boss Tecnologia
 *
 * @note		
 *	- A criação de sessão com banco de dados é mais segura, pois adiciona uma camada a mais que torna mais difícil
 *	a realização de alguma interferência externa mal intencionada.
 *	- A sessão gera um cookie de identificação onde o nome do cookie é o nome da sessão informado na criação com 
 *	um md5 (criptografia) e o value do cookie é o ID da sessão. Desta forma, pode-se utilizar o cookie para instanciar
 *	a sessão em outras áreas do sistema depois que foi criada.
 *	- Para consultar outras funcoes de sessao disponiveis, verifique a classe 'joomla/session/Session.php'
 *	- Existem também outros formatos que podem ser estudados para salvar a sessao além do banco de dados
 */

// Necessário para trabalhar com os namespaces
require_once __DIR__ . '/vendor/' . '/autoload.php';

// Classe database
use Joomla\Database\DatabaseDriver;
// Classe principal da sessao
use Joomla\Session\Session;
// Classe banco de dados da sessao
use Joomla\Session\Storage\Database;
// Classe input
use Joomla\Input\Input;

// Instancia objeto input
$input = new Input();

// Nome da nossa sessão de teste
$nomeSessao = "nobosstecnologia";

// Dados para a conexão com o banco de dados
$optionsDb = array(
	'driver' => 'mysql',
	'database' => 'johnny',
	'prefix' => 'jr_',
	'user' => 'root',
	'password' => '',
	'host' => 'localhost'
);

// Instancia objeto do banco de dados
$db = DatabaseDriver::getInstance($optionsDb);

// Dados para inicializacao da sessao
$optionsSession = array(
	'db' => $db,
	'name' => $nomeSessao,  // nome da sessao que será salvo com um md5
	//'id' => 'id_da_sessao',  // opcional (se nao informado eh gerado automaticamente)
	'cookie_domain' => '', // dominio do cookie a ser criado
	'cookie_path' => '/', // caminho em que o cookie é valido sobre o dominio informado. Se precisar valer para todos os diretórios, mantenha o valor '/'
	'expire' => '1' // passar em minutos o tempo em que a sessao deve expirar (se nao informado eh gerado com 15 minutos)
	//'security' => '' // informar separando por virgula que será convertido em array (se nao informado eh gerado automaticamente)
	//'force_ssl' => '' // informar true ou false (se nao informado eh gerado automaticamente
);

// Instancia objeto da sessao utilizando Database
$session = new Session('Database', $optionsSession);

// Inicia a sessao
$session->initialise($input);
$session->start();

/**
 * Prepara dados para salvar sessao no banco de dados
 * @note	Utilizando o framework puro sem o CMS se faz necessário realizar o insert da sessao no banco 'manualmente'
 */
$dadosdbSession = new stdClass();
$dadosdbSession->session_id = $session->getId();
$dadosdbSession->time = $session->getExpire();
$dadosdbSession->username = 'jreidel'; // Informe o username do usuário na sua aplicação
$dadosdbSession->userid = '1';  // Informe o id do usuário na aplicação (OBS: caso não queira manter a informação do ID, não informe esse campo e apague ele da tabela session)
//$dadosdbSession->data = json_encode($_SESSION); // Utilize apenas se quiser criar a sessão já armazenando dados nela
 
// Insere a sessão no banco de dados
$result = $db->insertObject('#__session', $dadosdbSession); 

// Libera memória da consulta
$db->freeResult();

// Registra um valor na sessao do banco de dados
// @note 	O valor eh armazenado junto as demais informacoes em json da coluna 'data' da tabela session do banco
$session->set('teste_variavel', 'teste_valor');

// Obtem um valor da sessao do banco de dados
echo $session->get('teste_variavel');

/*
 * Exemplo de como realizar um garbage collector para limpar sessões de outros usuários que expiraram e ainda estão no
 * banco de dados por não terem sido finalizadas através do 'logout' da sua aplicação.
 */

// Classe banco de dados da sessao necessária para essa função
use Joomla\Session\Storage\Database;
// Instancia objeto banco de dados da sessao
$sessionDb = new Database($optionsSession);
// Garbage collector para remover do banco sessoes expiradas
// Pode ser passado como parametro o lifetime maximo das sessoes que devem ser mantidas. o default eh 1440
$sessionDb->gc();

