<?php
/**
 * @package     Uso da biblioteca de sessao do Framework Joomla
 * @subpackage  Crian uma sessão normal (sem banco de dados)
 * @author		Johnny Salazar Reidel
 * @email		johnny@noboss.com.br
 * @copyright   No Boss Tecnologia
 *
 * @note		
 *	- A sessão gera um cookie de identificação onde o nome do cookie é o nome da sessão informado na criação com 
 *	um md5 (criptografia) e o value do cookie é o ID da sessão. Desta forma, pode-se utilizar o cookie para instanciar
 *	a sessão em outras áreas do sistema depois que foi criada.
 *	- Para consultar outras funcoes de sessao disponiveis, verifique a classe 'joomla/session/Session.php'
 */

// Necessário para trabalhar com os namespaces
require_once __DIR__ . '/vendor/' . '/autoload.php';

// Classe principal da sessao
use Joomla\Session\Session;
// Classe input
use Joomla\Input\Input;

// Instancia objeto input
$input = new Input();

// Nome da nossa sessão de teste
$nomeSessao = "nobosstecnologia";

// Dados para inicializacao da sessao
$optionsSession = array(
	'name' => $nomeSessao,  // nome da sessao que será salvo com um md5
	//'id' => 'id_da_sessao',  // opcional (se nao informado eh gerado automaticamente)
	'cookie_domain' => '', // dominio do cookie a ser criado
	'cookie_path' => '/', // caminho em que o cookie é valido sobre o dominio informado. Se precisar valer para todos os diretórios, mantenha o valor '/'
	'expire' => '1' // passar em minutos o tempo em que a sessao deve expirar (se nao informado eh gerado com 15 minutos)
);

// Inicia a sessao
$session = new Session('None', $optionsSession);
$session->initialise($input);
$session->start();

// Registra um valor na sessao
$session->set('teste_variavel', 'teste_valor');

// Obtem um valor da sessao
echo "Exemplo de valor obtido na sessão:".$session->get('teste_variavel');

//Destroi a sessao (incluindo banco de dados e cookie)
//$session->destroy($session->getId());
