<?php
/**
 * @package     Uso da biblioteca de sessao do Framework Joomla
 * @subpackage  Verificar estado da sessão gerada no banco de dados
 * @author		Johnny Salazar Reidel
 * @email		johnny@noboss.com.br
 * @copyright   No Boss Tecnologia
 *
 * @note		
 *	- Neste arquivo é mostrado como acessar uma sessão já existente e verificar o estado dela (ativa, inativa, expirada,..)
 *	- No caso da sessão estar com status de expirada é necessário destruí-la
 * 	- É importante lembrar de verificar se a sessão existe antes de inicia-la, pois caso não exista ela será recria-da com status de ativa
 *	- A chave para você saber como acessar a sessão existente é o nome da sessão, por isso utilize um tome que seja possível de recuperar 
 *	ao longo da navegação no site. No nosso exemplo foi utilizado o nome de sessão 'nobosstecnologia'
 */

// Necessário para trabalhar com os namespaces
require_once __DIR__ . '/vendor/' . '/autoload.php';

// Classe database
use Joomla\Database\DatabaseDriver;
// Classe principal da sessao
use Joomla\Session\Session;
// Classe input
use Joomla\Input\Input;

// Instancia objeto input
$input = new Input();

// Nome da nossa sessão de teste
$nomeSessao = "nobosstecnologia";

// Dados para a conexão com o banco de dados
$optionsDb = array(
	'driver' => 'mysql',
	'database' => 'johnny',
	'prefix' => 'jr_',
	'user' => 'root',
	'password' => '',
	'host' => 'localhost'
);

// Instancia objeto do banco de dados
$db = DatabaseDriver::getInstance($optionsDb);

// Cookie da sessao existe
if (isset($_COOKIE[md5($nomeSessao)])){
	$idSession = $_COOKIE[md5($nomeSessao)];

	// Dados para inicializacao da sessao (informar os mesmos utilizados na criação da sessão)
	$optionsSession = array(
		'db' => $db,
		'name' => $nomeSessao,
		'id' => $idSession,
		'expire' => '1',
		'cookie_domain' => '',
		'cookie_path' => '/'
	);

	// Inicia a sessão do banco de dados
	$session = new Session('Database', $optionsSession);
	$session->initialise($input);
	$session->start();

	// A sessão expirou e deve ser encerrada
	if ($session->getState() == 'expired'){
		echo 'A sessão expirou!';
		
		// Destroi a sessão, incluindo banco de dados e cookie
		$session->destroy($session->getId());
	}
	// A sessão está inativa
	else if ($session->getState() == 'inactive'){
		echo 'A sessão está inativa!';
	}
	// A sessão está ativa
	else if ($session->getState() == 'active'){
		echo 'A sessão está ativa!';
	}
	// Outros estados da sessão (destroyed, error)
	else{
		echo 'Status sessão: '.$session->getState().'<br>';

		// Exemplo de exibição da variável criada na sessão
		echo 'Váriavel salva na sessão: '.$session->get('teste_variavel');
	}
}
// A sessão não existe
else{
	echo 'A sessão informada não existe!';
}
